tempotools.integer_tempo_to_multiplier_tempo_pairs
==================================================

.. autofunction:: abjad.tools.tempotools.integer_tempo_to_multiplier_tempo_pairs.integer_tempo_to_multiplier_tempo_pairs
